(community)=
# Community

There are several different ways to be a part of the napari community. From
being a code or documentation contributor, to creating educational content or
examples, you are welcome to help develop and improve napari.

To ask questions and interact with the team, you can join our
[zulip chat](https://napari.zulipchat.com/login/) or participate in our
[meetings](./meeting_schedule).

If you are interested in contributing, check out our
[contributing guide](../developers/index).
